@@ -1,10 +1,12 @@
-# Copyright 2018-2024 contributors to the OpenLineage project
+# Copyright 2018-2025 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 
 from openlineage.client.generated import (
+    catalog_dataset,
     column_lineage_dataset,
     data_quality_assertions_dataset,
     data_quality_metrics_input_dataset,
+    dataset_type_dataset,
     dataset_version_dataset,
     datasource_dataset,
     documentation_dataset,
@@ -28,6 +30,9 @@ from openlineage.client.generated import (
     sql_job,
     storage_dataset,
     symlinks_dataset,
+    tags_dataset,
+    tags_job,
+    tags_run,
 )
 from openlineage.client.generated.base import (
     PRODUCER,
@@ -49,9 +54,11 @@ __all__ = [
     "OutputDatasetFacet",
     "RunFacet",
     "set_producer",
+    "catalog_dataset",
     "column_lineage_dataset",
     "data_quality_assertions_dataset",
     "data_quality_metrics_input_dataset",
+    "dataset_type_dataset",
     "dataset_version_dataset",
     "datasource_dataset",
     "documentation_dataset",
@@ -75,4 +82,7 @@ __all__ = [
     "sql_job",
     "storage_dataset",
     "symlinks_dataset",
+    "tags_dataset",
+    "tags_job",
+    "tags_run",
 ]
