@@ -30,10 +30,17 @@ from openlineage.client.run import (
 )
 from openlineage.client.transport.composite import CompositeTransport
 from openlineage.client.transport.console import ConsoleTransport
-from openlineage.client.transport.http import ApiKeyTokenProvider, HttpTransport, TokenProvider
+from openlineage.client.transport.http import (
+    ApiKeyTokenProvider,
+    HttpCompression,
+    HttpTransport,
+    TokenProvider,
+)
 from openlineage.client.transport.noop import NoopTransport
 from openlineage.client.uuid import generate_new_uuid
 
+from tests.test_async_http import closing_immediately
+
 if TYPE_CHECKING:
     from pathlib import Path
 
@@ -42,7 +49,7 @@ if TYPE_CHECKING:
 
 
 def test_client_fails_with_wrong_event_type() -> None:
-    client = OpenLineageClient(url="http://example.com", session=MagicMock())
+    client = OpenLineageClient(url="http://example.com")
 
     with pytest.raises(
         ValueError,
@@ -64,7 +71,7 @@ def test_client_fails_with_wrong_event_type() -> None:
 )
 def test_client_fails_to_create_with_wrong_url(url: str) -> None:
     with pytest.raises(ValueError, match=re.escape(url)):
-        OpenLineageClient(url=url, session=MagicMock())
+        OpenLineageClient(url=url)
 
 
 @pytest.mark.parametrize(
@@ -79,12 +86,13 @@ def test_client_fails_to_create_with_wrong_url(url: str) -> None:
     ],
 )
 def test_client_passes_to_create_with_valid_url(url: str, res: str) -> None:
-    assert OpenLineageClient(url=url, session=MagicMock()).transport.url == res
+    assert OpenLineageClient(url=url).transport.url == res
 
 
-def test_client_sends_proper_json_with_minimal_run_event() -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_client_sends_proper_json_with_minimal_run_event(mock_http_session_class) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
     client.emit(
         RunEvent(
             RunState.START,
@@ -101,18 +109,23 @@ def test_client_sends_proper_json_with_minimal_run_event() -> None:
         '"producer": "producer", "run": {"facets": {}, "runId": '
         f'"69f4acab-b87d-4fc0-b27b-8ea950370ff3"}}, "schemaURL": "{SCHEMA_URL}"}}'
     )
-    session.post.assert_called_with(
-        url="http://example.com/api/v1/lineage",
-        data=body,
-        headers={"Content-Type": "application/json"},
-        timeout=5.0,
-        verify=True,
-    )
+
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+
+    assert call_args.kwargs["url"] == "http://example.com/api/v1/lineage"
+    assert call_args.kwargs["headers"]["Content-Type"] == "application/json"
+
+    # Verify the content is the expected JSON
+    actual_content = call_args.kwargs["data"]
+    assert actual_content == body
 
 
-def test_client_sends_proper_json_with_minimal_dataset_event() -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_client_sends_proper_json_with_minimal_dataset_event(mock_http_session_class) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
 
     client.emit(
         DatasetEvent(
@@ -129,18 +142,23 @@ def test_client_sends_proper_json_with_minimal_dataset_event() -> None:
         '"2021-11-03T10:53:52.427343", "producer": "producer", '
         '"schemaURL": "datasetSchemaUrl"}'
     )
-    session.post.assert_called_with(
-        url="http://example.com/api/v1/lineage",
-        data=body,
-        headers={"Content-Type": "application/json"},
-        timeout=5.0,
-        verify=True,
-    )
+
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+
+    assert call_args.kwargs["url"] == "http://example.com/api/v1/lineage"
+    assert call_args.kwargs["headers"]["Content-Type"] == "application/json"
+
+    # Verify the content is the expected JSON
+    actual_content = call_args.kwargs["data"]
+    assert actual_content == body
 
 
-def test_client_sends_proper_json_with_minimal_job_event() -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_client_sends_proper_json_with_minimal_job_event(mock_http_session_class) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
 
     client.emit(
         JobEvent(
@@ -158,13 +176,16 @@ def test_client_sends_proper_json_with_minimal_job_event() -> None:
         '"schemaURL": "jobSchemaURL"}'
     )
 
-    session.post.assert_called_with(
-        url="http://example.com/api/v1/lineage",
-        data=body,
-        headers={"Content-Type": "application/json"},
-        timeout=5.0,
-        verify=True,
-    )
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+
+    assert call_args.kwargs["url"] == "http://example.com/api/v1/lineage"
+    assert call_args.kwargs["headers"]["Content-Type"] == "application/json"
+
+    # Verify the content is the expected JSON
+    actual_content = call_args.kwargs["data"]
+    assert actual_content == body
 
 
 def test_client_uses_passed_transport() -> None:
@@ -525,7 +546,8 @@ def test_config_property_loads_yaml(mock_get_config_content, mock_find_yaml):
     {"OPENLINEAGE_URL": "http://example.com", "OPENLINEAGE_ENDPOINT": "v7", "OPENLINEAGE_API_KEY": "xxx"},
 )
 def test_http_transport_from_env_variables() -> None:
-    transport = OpenLineageClient._http_transport_from_env_variables()  # noqa: SLF001
+    client = OpenLineageClient()
+    transport = client._http_transport_from_env_variables()  # noqa: SLF001
     assert transport.kind == HttpTransport.kind
     assert transport.url == "http://example.com"
     assert transport.endpoint == "v7"
@@ -604,6 +626,83 @@ def test_composite_transport_with_aliased_url_and_overriden_alias() -> None:
     assert transport.transports[0].kind == ConsoleTransport.kind
 
 
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE__TRANSPORT": '{"type": "async_http", "url": "https://data-obs-intake.datadoghq.com", '
+        '"auth": {"type": "apiKey", "apiKey": "YOUR_API_KEY"}}',
+    },
+)
+def test_configures_async_transport() -> None:
+    from openlineage.client.transport.async_http import AsyncHttpTransport
+
+    client = OpenLineageClient()
+    transport: AsyncHttpTransport = client.transport
+    with closing_immediately(transport) as transport:
+        assert transport.kind == "async_http"
+
+
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE_URL": "http://example.com",
+        "OPENLINEAGE_ENDPOINT": "api/v2/lineage",
+        "OPENLINEAGE_API_KEY": "YOUR_API_KEY",
+        "OPENLINEAGE__TRANSPORT__TYPE": "async_http",
+    },
+)
+def test_async_transport_with_overwritten_transport_type() -> None:
+    from openlineage.client.transport.async_http import AsyncHttpTransport
+
+    client = OpenLineageClient()
+    transport: AsyncHttpTransport = client.transport
+    assert transport.kind == "async_http"
+    assert transport.url == "http://example.com"
+    assert transport.endpoint == "api/v2/lineage"
+    assert transport.config.auth.api_key == "YOUR_API_KEY"
+
+
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE_URL": "http://example.com",
+        "OPENLINEAGE__TRANSPORT__TYPE": "async_http",
+        "OPENLINEAGE__TRANSPORT__URL": "http://this.should.have.priority.com",
+    },
+)
+def test_async_transport_with_priority_overwrite() -> None:
+    from openlineage.client.transport.async_http import AsyncHttpTransport
+
+    client = OpenLineageClient()
+    transport: AsyncHttpTransport = client.transport
+    assert transport.kind == "async_http"
+    assert transport.url == "http://this.should.have.priority.com"
+
+
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE_URL": "http://example.com",
+        "OPENLINEAGE__TRANSPORT__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__ANOTHER__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__ANOTHER__PRIORITY": "4",
+    },
+)
+def test_composite_transport_with_sorted_by_priority() -> None:
+    transport: CompositeTransport = OpenLineageClient().transport
+    expected_priority = 4
+    assert transport.kind == CompositeTransport.kind
+    assert transport.config.sort_transports is True
+    assert len(transport.transports) == 2  # noqa: PLR2004
+    assert transport.transports[0].kind == ConsoleTransport.kind
+    assert transport.transports[0].priority == expected_priority
+    assert transport.transports[0].name == "another"
+    assert transport.transports[1].kind == HttpTransport.kind
+    assert transport.transports[1].name == "default_http"
+    assert transport.transports[1].priority == 0
+
+
 @patch.dict(
     os.environ,
     {
@@ -1161,3 +1260,271 @@ def test_client_does_not_update_run_tags_for_job_events(transport, job_event_mul
         event_tags = sorted(transport.event.job.facets["tags"].tags, key=lambda x: x.key)
         expected_tags = sorted(tags, key=lambda x: x.key)
         assert event_tags == expected_tags
+
+
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE_URL": "http://example.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__DEFAULT_HTTP": "{}",
+        "OPENLINEAGE__TRANSPORT__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TYPE": "console",
+    },
+)
+def test_client_transport_from_env_var_precedence_over_url_without_aliasing():
+    user_config = {}
+    transport = OpenLineageClient(config=user_config).transport
+    assert transport.kind == "composite"
+    assert len(transport.transports) == 1
+    assert transport.transports[0].kind == "console"
+
+
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE_URL": "http://example.com",
+        "OPENLINEAGE__TRANSPORT__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TYPE": "console",
+    },
+)
+def test_client_transport_from_env_var_precedence_over_url_with_aliasing():
+    user_config = {}
+    transport = OpenLineageClient(config=user_config).transport
+    assert transport.kind == "composite"
+    assert len(transport.transports) == 2
+    assert transport.transports[0].kind == "console"
+    assert transport.transports[1].kind == "http"
+    assert transport.transports[1].url == "http://example.com"
+
+
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE_URL": "http://example.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__DEFAULT_HTTP": "{}",
+        "OPENLINEAGE__TRANSPORT__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__NAME": "some_name",
+        "OPENLINEAGE__TRANSPORT__CONTINUE_ON_FAILURE": "false",
+        "OPENLINEAGE__TRANSPORT__CONTINUE_ON_SUCCESS": "false",
+        "OPENLINEAGE__TRANSPORT__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__CONTINUE_ON_FAILURE": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__CONTINUE_ON_SUCCESS": "false",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__PRIORITY": "-1",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_FIRST__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_FIRST__PRIORITY": "2",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__TYPE": "http",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__URL": "http://inner.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__COMPRESSION": "gzip",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__SECOND__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__SECOND__PRIORITY": "1",
+    },
+)
+def test_client_transport_from_env_var_precedence_composite_with_priority():
+    user_config = {}
+    transport = OpenLineageClient(config=user_config).transport
+    assert transport.kind == "composite"
+    assert transport.name == "some_name"
+    assert transport.config.continue_on_failure is False
+    assert transport.config.continue_on_success is False
+    assert transport.config.sort_transports is True
+    assert len(transport.transports) == 2
+    assert transport.transports[0].kind == "console"
+    assert transport.transports[0].name == "second"
+    assert transport.transports[0].priority == 1
+
+    composite_transport = transport.transports[1]
+    assert composite_transport.kind == "composite"
+    assert composite_transport.name == "first"
+    assert composite_transport.priority == -1
+    assert composite_transport.config.continue_on_failure is True
+    assert composite_transport.config.continue_on_success is False
+    assert composite_transport.config.sort_transports is True
+    assert len(composite_transport.transports) == 2
+    assert composite_transport.transports[0].kind == "console"
+    assert composite_transport.transports[0].name == "inner_first"
+    assert composite_transport.transports[0].priority == 2
+    assert composite_transport.transports[1].kind == "http"
+    assert composite_transport.transports[1].name == "inner_backup"
+    assert composite_transport.transports[1].priority == 0
+    assert composite_transport.transports[1].url == "http://inner.com"
+    assert composite_transport.transports[1].compression == HttpCompression.GZIP
+
+
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE_URL": "http://example.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__DEFAULT_HTTP": "{}",
+        "OPENLINEAGE__TRANSPORT__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__NAME": "some_name",
+        "OPENLINEAGE__TRANSPORT__CONTINUE_ON_FAILURE": "false",
+        "OPENLINEAGE__TRANSPORT__CONTINUE_ON_SUCCESS": "false",
+        "OPENLINEAGE__TRANSPORT__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__CONTINUE_ON_FAILURE": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__CONTINUE_ON_SUCCESS": "false",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__PRIORITY": "-1",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_FIRST__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_FIRST__PRIORITY": "2",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__TYPE": "http",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__URL": "http://inner.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__COMPRESSION": "gzip",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__SECOND__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__SECOND__PRIORITY": "1",
+    },
+)
+def test_client_transport_from_env_var_precedence_composite_with_priority_and_user_config():
+    user_config = {"transport": {"type": "console", "name": "user_transport"}}
+    transport = OpenLineageClient(config=user_config).transport
+    assert transport.kind == "console"
+    assert transport.name == "user_transport"
+
+
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE_URL": "http://example.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__DEFAULT_HTTP": "{}",
+        "OPENLINEAGE__TRANSPORT__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__NAME": "some_name",
+        "OPENLINEAGE__TRANSPORT__CONTINUE_ON_FAILURE": "false",
+        "OPENLINEAGE__TRANSPORT__CONTINUE_ON_SUCCESS": "false",
+        "OPENLINEAGE__TRANSPORT__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__CONTINUE_ON_FAILURE": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__CONTINUE_ON_SUCCESS": "false",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__PRIORITY": "-1",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_FIRST__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_FIRST__PRIORITY": "2",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__TYPE": "http",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__URL": "http://inner.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__COMPRESSION": "gzip",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__SECOND__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__SECOND__PRIORITY": "1",
+    },
+)
+def test_client_transport_from_env_var_composite_with_user_config_merging():
+    user_config = {"transport": {"type": "composite", "name": "user_transport"}}
+    transport = OpenLineageClient(config=user_config).transport
+    assert transport.kind == "composite"
+    assert transport.name == "user_transport"
+    assert transport.config.continue_on_failure is False
+    assert transport.config.continue_on_success is False
+    assert transport.config.sort_transports is True
+    assert len(transport.transports) == 2
+    assert transport.transports[0].kind == "console"
+    assert transport.transports[0].name == "second"
+    assert transport.transports[0].priority == 1
+
+    composite_transport = transport.transports[1]
+    assert composite_transport.kind == "composite"
+    assert composite_transport.name == "first"
+    assert composite_transport.priority == -1
+    assert composite_transport.config.continue_on_failure is True
+    assert composite_transport.config.continue_on_success is False
+    assert composite_transport.config.sort_transports is True
+    assert len(composite_transport.transports) == 2
+    assert composite_transport.transports[0].kind == "console"
+    assert composite_transport.transports[0].name == "inner_first"
+    assert composite_transport.transports[0].priority == 2
+    assert composite_transport.transports[1].kind == "http"
+    assert composite_transport.transports[1].name == "inner_backup"
+    assert composite_transport.transports[1].priority == 0
+    assert composite_transport.transports[1].url == "http://inner.com"
+    assert composite_transport.transports[1].compression == HttpCompression.GZIP
+
+
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE_URL": "http://example.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__DEFAULT_HTTP": "{}",
+        "OPENLINEAGE__TRANSPORT__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__NAME": "some_name",
+        "OPENLINEAGE__TRANSPORT__CONTINUE_ON_FAILURE": "false",
+        "OPENLINEAGE__TRANSPORT__CONTINUE_ON_SUCCESS": "false",
+        "OPENLINEAGE__TRANSPORT__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__CONTINUE_ON_FAILURE": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__CONTINUE_ON_SUCCESS": "false",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__PRIORITY": "-1",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_FIRST__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_FIRST__PRIORITY": "2",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__TYPE": "http",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__URL": "http://inner.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__COMPRESSION": "gzip",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__SECOND__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__SECOND__PRIORITY": "1",
+    },
+)
+def test_client_transport_from_env_var_composite_with_user_config_overwrite_transports():
+    user_config = {
+        "transport": {
+            "type": "composite",
+            "name": "user_transport",
+            "transports": [
+                {"type": "console", "name": "should_be_second", "priority": "1"},
+                {"type": "console", "name": "should_be_first", "priority": "2"},
+            ],
+        }
+    }
+    transport = OpenLineageClient(config=user_config).transport
+    assert transport.kind == "composite"
+    assert transport.name == "user_transport"
+    assert transport.config.continue_on_failure is False  # This is still coming from env vars
+    assert transport.config.continue_on_success is False  # This is still coming from env vars
+    assert transport.config.sort_transports is True  # This is still coming from env vars
+    assert len(transport.transports) == 2
+    assert transport.transports[0].kind == "console"
+    assert transport.transports[0].name == "should_be_first"
+    assert transport.transports[0].priority == 2
+    assert transport.transports[1].kind == "console"
+    assert transport.transports[1].name == "should_be_second"
+    assert transport.transports[1].priority == 1
+
+
+@patch.dict(
+    os.environ,
+    {
+        "OPENLINEAGE_URL": "http://example.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__DEFAULT_HTTP": "{}",
+        "OPENLINEAGE__TRANSPORT__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__NAME": "some_name",
+        "OPENLINEAGE__TRANSPORT__CONTINUE_ON_FAILURE": "false",
+        "OPENLINEAGE__TRANSPORT__CONTINUE_ON_SUCCESS": "false",
+        "OPENLINEAGE__TRANSPORT__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TYPE": "composite",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__CONTINUE_ON_FAILURE": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__CONTINUE_ON_SUCCESS": "false",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__SORT_TRANSPORTS": "true",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__PRIORITY": "-1",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_FIRST__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_FIRST__PRIORITY": "2",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__TYPE": "http",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__URL": "http://inner.com",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__FIRST__TRANSPORTS__INNER_BACKUP__COMPRESSION": "gzip",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__SECOND__TYPE": "console",
+        "OPENLINEAGE__TRANSPORT__TRANSPORTS__SECOND__PRIORITY": "1",
+    },
+)
+def test_client_transport_from_env_var_composite_with_user_config_non_composite():
+    user_config = {
+        "transport": {
+            "type": "http",
+            "name": "user_transport",
+            "url": "http://user.com",
+            "compression": "gzip",
+        }
+    }
+    transport = OpenLineageClient(config=user_config).transport
+    assert transport.kind == "http"
+    assert transport.name == "user_transport"
+    assert transport.priority == 0
+    assert transport.url == "http://user.com"
+    assert transport.endpoint == "api/v1/lineage"
+    assert transport.compression == HttpCompression.GZIP
