@@ -5,7 +5,6 @@ from __future__ import annotations
 import copy
 import json
 from typing import Any
-from unittest.mock import MagicMock
 
 import pytest
 from openlineage.client.client import OpenLineageClient
@@ -31,7 +30,7 @@ from openlineage.client.run import SCHEMA_URL, Dataset, Job, Run, RunEvent, RunS
 from openlineage.client.serde import Serde
 
 
-@pytest.fixture()
+@pytest.fixture
 def event() -> dict[str, Any]:
     return {
         "eventType": "START",
@@ -58,9 +57,10 @@ def event() -> dict[str, Any]:
     }
 
 
-def test_symlink_dataset_facet(event: dict[str, Any]) -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_symlink_dataset_facet(mock_http_session_class, event: dict[str, Any]) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
 
     symlink_facet = {
         "_producer": "https://github.com/OpenLineage/OpenLineage/tree/0.0.1/client/python",
@@ -103,7 +103,10 @@ def test_symlink_dataset_facet(event: dict[str, Any]) -> None:
         ),
     )
 
-    event_sent = json.loads(session.post.call_args.kwargs["data"])
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+    event_sent = json.loads(call_args.kwargs["data"])
 
     expected_event = copy.deepcopy(event)
     expected_event["outputs"][0]["facets"] = {}
@@ -112,9 +115,10 @@ def test_symlink_dataset_facet(event: dict[str, Any]) -> None:
     assert expected_event == event_sent
 
 
-def test_storage_dataset_facet(event: dict[str, Any]) -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_storage_dataset_facet(mock_http_session_class, event: dict[str, Any]) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
 
     storage_facet = {
         "storageLayer": "iceberg",
@@ -147,7 +151,10 @@ def test_storage_dataset_facet(event: dict[str, Any]) -> None:
         ),
     )
 
-    event_sent = json.loads(session.post.call_args.kwargs["data"])
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+    event_sent = json.loads(call_args.kwargs["data"])
 
     expected_event = copy.deepcopy(event)
     expected_event["outputs"][0]["facets"] = {}
@@ -156,9 +163,10 @@ def test_storage_dataset_facet(event: dict[str, Any]) -> None:
     assert expected_event == event_sent
 
 
-def test_ownership_job_facet(event: dict[str, Any]) -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_ownership_job_facet(mock_http_session_class, event: dict[str, Any]) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
 
     ownership_job_facet = {
         "owners": [
@@ -199,7 +207,10 @@ def test_ownership_job_facet(event: dict[str, Any]) -> None:
         ),
     )
 
-    event_sent = json.loads(session.post.call_args.kwargs["data"])
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+    event_sent = json.loads(call_args.kwargs["data"])
 
     expected_event = copy.deepcopy(event)
     expected_event["job"]["facets"] = {}
@@ -208,9 +219,10 @@ def test_ownership_job_facet(event: dict[str, Any]) -> None:
     assert expected_event == event_sent
 
 
-def test_dataset_version_dataset_facet(event: dict[str, Any]) -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_dataset_version_dataset_facet(mock_http_session_class, event: dict[str, Any]) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
 
     dataset_version_facet = {
         "datasetVersion": "v0.1",
@@ -244,7 +256,10 @@ def test_dataset_version_dataset_facet(event: dict[str, Any]) -> None:
         ),
     )
 
-    event_sent = json.loads(session.post.call_args.kwargs["data"])
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+    event_sent = json.loads(call_args.kwargs["data"])
 
     expected_event = copy.deepcopy(event)
     expected_event["outputs"][0]["facets"] = {}
@@ -253,9 +268,10 @@ def test_dataset_version_dataset_facet(event: dict[str, Any]) -> None:
     assert expected_event == event_sent
 
 
-def test_lifecycle_state_change_dataset_facet(event: dict[str, Any]) -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_lifecycle_state_change_dataset_facet(mock_http_session_class, event: dict[str, Any]) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
 
     lifecycle_state_change_dataset_facet = {
         "lifecycleStateChange": "DROP",
@@ -297,7 +313,10 @@ def test_lifecycle_state_change_dataset_facet(event: dict[str, Any]) -> None:
         ),
     )
 
-    event_sent = json.loads(session.post.call_args.kwargs["data"])
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+    event_sent = json.loads(call_args.kwargs["data"])
 
     dataset_facets = {}
     dataset_facets["lifecycleStateChange"] = lifecycle_state_change_dataset_facet
@@ -307,9 +326,10 @@ def test_lifecycle_state_change_dataset_facet(event: dict[str, Any]) -> None:
     assert expected_event == event_sent
 
 
-def test_ownership_dataset_facet(event: dict[str, Any]) -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_ownership_dataset_facet(mock_http_session_class, event: dict[str, Any]) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
 
     ownership_dataset_facet = {
         "owners": [
@@ -353,7 +373,10 @@ def test_ownership_dataset_facet(event: dict[str, Any]) -> None:
         ),
     )
 
-    event_sent = json.loads(session.post.call_args.kwargs["data"])
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+    event_sent = json.loads(call_args.kwargs["data"])
 
     expected_event = copy.deepcopy(event)
     expected_event["outputs"][0]["facets"] = {}
@@ -362,9 +385,10 @@ def test_ownership_dataset_facet(event: dict[str, Any]) -> None:
     assert expected_event == event_sent
 
 
-def test_column_lineage_dataset_facet(event: dict[str, Any]) -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_column_lineage_dataset_facet(mock_http_session_class, event: dict[str, Any]) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
 
     column_lineage_dataset_facet = {
         "fields": {
@@ -422,7 +446,10 @@ def test_column_lineage_dataset_facet(event: dict[str, Any]) -> None:
         ),
     )
 
-    event_sent = json.loads(session.post.call_args.kwargs["data"])
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+    event_sent = json.loads(call_args.kwargs["data"])
 
     expected_event = copy.deepcopy(event)
     expected_event["outputs"][0]["facets"] = {}
@@ -431,9 +458,10 @@ def test_column_lineage_dataset_facet(event: dict[str, Any]) -> None:
     assert expected_event == event_sent
 
 
-def test_job_type_job_facet(event: dict[str, Any]) -> None:
-    session = MagicMock()
-    client = OpenLineageClient(url="http://example.com", session=session)
+def test_job_type_job_facet(mock_http_session_class, event: dict[str, Any]) -> None:
+    mock_session_class, mock_client, mock_response = mock_http_session_class
+
+    client = OpenLineageClient(url="http://example.com")
 
     job_type_facet = {
         "processingType": "BATCH",
@@ -459,7 +487,10 @@ def test_job_type_job_facet(event: dict[str, Any]) -> None:
         ),
     )
 
-    event_sent = json.loads(session.post.call_args.kwargs["data"])
+    # Verify the post was called with correct parameters
+    mock_client.post.assert_called_once()
+    call_args = mock_client.post.call_args
+    event_sent = json.loads(call_args.kwargs["data"])
 
     expected_event = copy.deepcopy(event)
     expected_event["outputs"] = []
